<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin paveikslų žiūryklė</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versija:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>paveikslas</translation>
    </message>
    <message>
        <source>images</source>
        <translation>paveikslai(-ų)</translation>
    </message>
    <message>
        <source>album</source>
        <translation>albumas</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>albumai(-ų)</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Tvarkyti sinchronizavimą</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Sinchronizuojama: </translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Gerai</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Naujas albumas</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Be pavadinimo</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Paskiausiai importuoti</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mano mėgstami</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Ar tikrai norite ištrinti šį albumą?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Atgal</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mano mėgstami</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Laiko juosta</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Jūs galite pridėti sinchronizavimo katalogą arba vilkti paveikslus į laiko juostą</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Be pavadinimo</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Žiūrėti</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Skaidrių rodymas</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Pervadinti</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin paveikslų žiūryklė</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Paveikslai</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Gerai</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Ar tikrai norite pridėti paveikslus į albumą?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Sinchronizuoti ir sukurti</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Sinchronizuoti</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Ar tikrai norite pridėti į sinchronizavimo sąrašą ir sukurti albumą tokiu pačiu pavadinimu kaip ir šis aplankas?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Eksportuota sėkmingai</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Nepavyko eksportuoti</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Įrašyti</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Ar tikrai norite perkelti paveikslus į ŠIUŠKLINĘ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Paveikslo informacija</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Šiame faile yra keli puslapiai, norėdami peržiūrėti visus puslapius, naudokite programą Evince.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Žiūrėti</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Skaidrių rodymas</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Spausdinti</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopijuoti į iškarpinę</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Šalinti iš albumo</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Mėgstamas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nebemėgstamas</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pasukti pagal laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pasukti prieš laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nustatyti kaip darbalaukio foną</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Rodyti failų tvarkytuvėje</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Paveikslo informacija</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Jūs galite pridėti sinchronizavimo katalogą arba vilkti paveikslus į laiko juostą</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Pridėti į albumą</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Pridėti į naują albumą</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Atverti katalogą</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Jūs neturite leidimų peržiūrėti paveikslą</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Pavadinimas</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipas</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Fotografavimo data</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Keitimo data</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Matmenys</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Failo dydis</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Spalvų erdvė</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Išlaikymo veiksena</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Išlaikymo programa</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Išlaikymas</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blykstė</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Diafragma</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Židinio nuotolis</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Didžiausia diafragma</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Matavimo veiksena</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Baltos spalvos balansas</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Blykstės kompensavimas</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Fotoaparato modelis</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Objektyvo modelis</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Nekeisti mastelio</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Talpinti puslapį į paveikslą</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Talpinti paveikslą į puslapį</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Keisti mastelį į:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milimetrų</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centimetrų</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Colių</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Paveikslo pozicija</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Mastelio keitimas</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Paveikslo nustatymai</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Paveikslo nustatymai</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Langinės</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Perjungiklis</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Slinkimas</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Žiedas</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Pasirinkti katalogą</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Šis katalogas yra išjungtas sinchronizavimui</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Pridėti aplanką</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Sinchronizuojamų katalogų tvarkymas</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Katalogų sąrašas yra tuščias</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Atsisakyti sinchronizavimo</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Paveikslai</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Įrenginys buvo pašalintas</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Šio katalogo daugiau nebėra</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Apskaičiuojama...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Paveikslo žiūrėjimas</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Albumas</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Žiūrėti</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Skaidrių rodymas</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Užbaigti rodymą</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Šalinti iš albumo</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Mėgstamas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nebemėgstamas</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pasukti pagal laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pasukti prieš laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nustatyti kaip darbalaukio foną</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Rodyti failų tvarkytuvėje</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Paveikslo informacija</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Ankstesnis</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Kitas</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Ankstesnis ekranas</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Kitas ekranas</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Naujas albumas</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Pervadinti</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Išeiti</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Rodyti trumpinius</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Prašome įvesti naują trumpinį</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Trumpiniai</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Paveikslo rodymas</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Albumas</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Atkurti numatytuosius</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Žiūrėti</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Skaidrių rodymas</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Užbaigti rodymą</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Spausdinti</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Šalinti iš albumo</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Mėgstamas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nebemėgstamas</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pasukti pagal laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pasukti prieš laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nustatyti kaip darbalaukio foną</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Rodyti failų tvarkytuvėje</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Paveikslo informacija</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Naujas albumas</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Pervadinti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Užbaigti rodymą</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Pristabdyti/Tęsti</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Slinkimo nustatymai</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Perjungimo efektas</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Trukmė</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Perjungimo trukmė</translation>
    </message>
    <message>
        <source>second</source>
        <translation>sekundės</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Atgal</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Paveikslų tvarkymas</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mano mėgstami</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Dydis 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Talpinti į langą</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pasukti prieš laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pasukti pagal laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nebemėgstamas</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Mėgstamas</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nerasta jokių paveikslo failų</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Atverti paveikslą</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 paveikslas</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 paveikslai(-ų)</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Tvarkyti sinchronizavimą</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Sinchronizuojama: </translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Albumas</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Jūs galite pridėti sinchronizavimo katalogą arba vilkti paveikslus į laiko juostą</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Pridėti į albumą</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Pridėti į naują albumą</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Žiūrėti</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Skaidrių rodymas</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Spausdinti</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopijuoti į iškarpinę</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Mėgstamas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nebemėgstamas</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pasukti pagal laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pasukti prieš laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nustatyti kaip darbalaukio foną</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Rodyti failų tvarkytuvėje</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Paveikslo informacija</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Slinkimo nustatymai</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efektai</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Trukmė</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Trumpiniai</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Rodymas</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Albumas</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mano mėgstami</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Paskiausiai importuoti</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Naujas albumas</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Deepin paveikslų žiūryklė yra šiuolaikinė ir glotni paveikslų tvarkytuvė.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Jos pagrindinės ypatybės yra paveikslų tvarkymas, paveikslų rodymas bei pagrindinės paveikslų redagavimo funkcijos.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tamsi tema</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Deepin paveikslų žiūryklė yra paveikslų peržiūros įrankis su šiuolaikine sąsaja ir glotniu našumu.</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Laiko juosta</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Pridėti į albumą</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Pridėti į naują albumą</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Išeiti iš viso ekrano</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Skaidrių rodymas</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Spausdinti</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopijuoti į iškarpinę</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Šalinti iš albumo</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Mėgstamas</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nebemėgstamas</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Rodyti naršymo langą</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Slėpti naršymo langą</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pasukti pagal laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pasukti prieš laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nustatyti kaip darbalaukio foną</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Rodyti failų tvarkytuvėje</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Paveikslo informacija</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Atverti paveikslą</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Visi paveikslai</translation>
    </message>
</context>
</TS>